@@ -6,8 +6,10 @@ import time
 import calendar
 import unittest
 import platform
+import warnings
 
 from dateutil import parser
+from dateutil.tz import tzlocal
 
 real_time = time.time
 real_localtime = time.localtime
@@ -168,7 +170,9 @@ class FakeDatetime(with_metaclass(FakeDatetimeMeta, real_datetime, FakeDate)):
         else:
             return result
 
-    def astimezone(self, tz):
+    def astimezone(self, tz=None):
+        if tz is None:
+            tz = tzlocal()
         return datetime_to_fakedatetime(real_datetime.astimezone(self, tz))
 
     @classmethod
@@ -236,6 +240,23 @@ def pickle_fake_datetime(datetime_):
     )
 
 
+def _parse_time_to_freeze(time_to_freeze_str):
+    """Parses all the possible inputs for freeze_time
+    :returns: a naive ``datetime.datetime`` object
+    """
+    if time_to_freeze_str is None:
+        time_to_freeze_str = datetime.datetime.utcnow()
+
+    if isinstance(time_to_freeze_str, datetime.datetime):
+        time_to_freeze = time_to_freeze_str
+    elif isinstance(time_to_freeze_str, datetime.date):
+        time_to_freeze = datetime.datetime.combine(time_to_freeze_str, datetime.time())
+    else:
+        time_to_freeze = parser.parse(time_to_freeze_str)
+
+    return convert_to_timezone_naive(time_to_freeze)
+
+
 class TickingDateTimeFactory(object):
 
     def __init__(self, time_to_freeze, start):
@@ -257,21 +278,18 @@ class FrozenDateTimeFactory(object):
     def tick(self, delta=datetime.timedelta(seconds=1)):
         self.time_to_freeze += delta
 
+    def move_to(self, target_datetime):
+        """Moves frozen date to the given ``target_datetime``"""
+        target_datetime = _parse_time_to_freeze(target_datetime)
+        delta = target_datetime - self.time_to_freeze
+        self.tick(delta=delta)
+
 
 class _freeze_time(object):
 
     def __init__(self, time_to_freeze_str, tz_offset, ignore, tick):
-        if time_to_freeze_str is None:
-            time_to_freeze = datetime.datetime.utcnow()
-        if isinstance(time_to_freeze_str, datetime.datetime):
-            time_to_freeze = time_to_freeze_str
-        elif isinstance(time_to_freeze_str, datetime.date):
-            time_to_freeze = datetime.datetime.combine(time_to_freeze_str, datetime.time())
-        else:
-            time_to_freeze = parser.parse(time_to_freeze_str)
-        time_to_freeze = convert_to_timezone_naive(time_to_freeze)
 
-        self.time_to_freeze = time_to_freeze
+        self.time_to_freeze = _parse_time_to_freeze(time_to_freeze_str)
         self.tz_offset = tz_offset
         self.ignore = tuple(ignore)
         self.tick = tick
@@ -312,7 +330,9 @@ class _freeze_time(object):
         else:
 
             seen = set()
-            for base_klass in klass.mro():
+
+            klasses = klass.mro() if hasattr(klass, 'mro') else [klass] + list(klass.__bases__)
+            for base_klass in klasses:
                 for (attr, attr_value) in base_klass.__dict__.items():
                     if attr.startswith('_') or attr in seen:
                         continue
@@ -373,25 +393,28 @@ class _freeze_time(object):
         # Save the current loaded modules
         self.modules_at_start = set(sys.modules.keys())
 
-        for mod_name, module in list(sys.modules.items()):
-            if mod_name is None or module is None:
-                continue
-            elif mod_name.startswith(self.ignore):
-                continue
-            elif (not hasattr(module, "__name__") or module.__name__ in ('datetime', 'time')):
-                continue
-            for module_attribute in dir(module):
-                if module_attribute in real_names:
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore')
+
+            for mod_name, module in list(sys.modules.items()):
+                if mod_name is None or module is None:
                     continue
-                try:
-                    attribute_value = getattr(module, module_attribute)
-                except (ImportError, AttributeError, TypeError):
-                    # For certain libraries, this can result in ImportError(_winreg) or AttributeError (celery)
+                elif mod_name.startswith(self.ignore):
                     continue
-                fake = fakes.get(id(attribute_value))
-                if fake:
-                    setattr(module, module_attribute, fake)
-                    add_change((module, module_attribute, attribute_value))
+                elif (not hasattr(module, "__name__") or module.__name__ in ('datetime', 'time')):
+                    continue
+                for module_attribute in dir(module):
+                    if module_attribute in real_names:
+                        continue
+                    try:
+                        attribute_value = getattr(module, module_attribute)
+                    except (ImportError, AttributeError, TypeError):
+                        # For certain libraries, this can result in ImportError(_winreg) or AttributeError (celery)
+                        continue
+                    fake = fakes.get(id(attribute_value))
+                    if fake:
+                        setattr(module, module_attribute, fake)
+                        add_change((module, module_attribute, attribute_value))
 
         datetime.datetime.times_to_freeze.append(time_to_freeze)
         datetime.datetime.tz_offsets.append(self.tz_offset)
@@ -419,26 +442,29 @@ class _freeze_time(object):
             # Restore modules loaded after start()
             modules_to_restore = set(sys.modules.keys()) - self.modules_at_start
             self.modules_at_start = set()
-            for mod_name in modules_to_restore:
-                module = sys.modules.get(mod_name, None)
-                if mod_name is None or module is None:
-                    continue
-                elif mod_name.startswith(self.ignore):
-                    continue
-                elif (not hasattr(module, "__name__") or module.__name__ in ('datetime', 'time')):
-                    continue
-                for module_attribute in dir(module):
-                    if module_attribute in self.fake_names:
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore')
+                for mod_name in modules_to_restore:
+                    module = sys.modules.get(mod_name, None)
+                    if mod_name is None or module is None:
                         continue
-                    try:
-                        attribute_value = getattr(module, module_attribute)
-                    except (ImportError, AttributeError, TypeError):
-                        # For certain libraries, this can result in ImportError(_winreg) or AttributeError (celery)
+                    elif mod_name.startswith(self.ignore):
                         continue
+                    elif (not hasattr(module, "__name__") or module.__name__ in ('datetime', 'time')):
+                        continue
+                    for module_attribute in dir(module):
 
-                    real = self.reals.get(id(attribute_value))
-                    if real:
-                        setattr(module, module_attribute, real)
+                        if module_attribute in self.fake_names:
+                            continue
+                        try:
+                            attribute_value = getattr(module, module_attribute)
+                        except (ImportError, AttributeError, TypeError):
+                            # For certain libraries, this can result in ImportError(_winreg) or AttributeError (celery)
+                            continue
+
+                        real = self.reals.get(id(attribute_value))
+                        if real:
+                            setattr(module, module_attribute, real)
 
         time.time = time.time.previous_time_function
         time.gmtime = time.gmtime.previous_gmtime_function
@@ -466,7 +492,7 @@ def freeze_time(time_to_freeze=None, tz_offset=0, ignore=None, tick=False):
     except NameError:
         string_type = str
 
-    if not isinstance(time_to_freeze, (string_type, datetime.date)):
+    if not isinstance(time_to_freeze, (type(None), string_type, datetime.date)):
         raise TypeError(('freeze_time() expected None, a string, date instance, or '
                          'datetime instance, but got type {0}.').format(type(time_to_freeze)))
     if tick and not _is_cpython:
@@ -476,6 +502,8 @@ def freeze_time(time_to_freeze=None, tz_offset=0, ignore=None, tick=False):
         ignore = []
     ignore.append('six.moves')
     ignore.append('django.utils.six.moves')
+    ignore.append('threading')
+    ignore.append('Queue')
     return _freeze_time(time_to_freeze, tz_offset, ignore, tick)
 
 
@@ -504,4 +532,6 @@ except ImportError:
     pass
 else:
     pymysql.converters.encoders[FakeDate] = pymysql.converters.encoders[real_date]
+    pymysql.converters.conversions[FakeDate] = pymysql.converters.encoders[real_date]
     pymysql.converters.encoders[FakeDatetime] = pymysql.converters.encoders[real_datetime]
+    pymysql.converters.conversions[FakeDatetime] = pymysql.converters.encoders[real_datetime]
